import scattool

from scattool.shared import ScatApp
from pathlib import Path

import logging
logger = logging.getLogger(__name__)

import scattool.locales

class ScatCli(ScatApp):

    def main(self):
        logger.info("Starting the SCAT CLI")
        print(self.profiles.list_all())
        print(self.configuration.orgconfig)
        print(self.configuration.encryption)


        # logger.info("HELLO")
        # package = self.open_local_package("aip", "525c9827-9921-5ab0-825d-9a2b1acfcc66")
        # print(package)


        # logger.info("HELLO2")
        # package = self.open_local_package("aip", "4ee52c8d-4bae-5caa-a4f0-5ec90b5abcaf")
        # print(package)

        logger.info("HELLO")
        package = self.open_package(Path("/home/ccare/.scat/local_aip_store/ff172daa-c798-5322-a105-277a5fffd2b8"))
        print(package)

        x = self.logs.list_logs()
        n, xx = x[0]
        print(self.logs.show_log(n))

        print(self.get_version_identifier())
